@@ -15,12 +15,8 @@ double MultisetPermRowNum(int n, int r, const std::vector<int> &myReps);
 // not produce negative results and is thus used in determining whether
 // gmp analogs are necessary
 double MultisetCombRowNum(int n, int r, const std::vector<int> &Reps);
-    
-void nextFullPerm(int *myArray, unsigned long int n1,
-                  unsigned long int n2);
-
-void nextPartialPerm(int *myArray, unsigned long int r,
-                     unsigned long int r1, unsigned long int n,
-                     unsigned long int lastElem);
+void nextFullPerm(int *myArray, std::size_t n1, std::size_t n2);
+void nextPartialPerm(int *myArray, std::size_t r, std::size_t r1,
+                     std::size_t n, std::size_t lastElem);
     
 #endif
